##  Webhook Events
Subscribe to the following webhook events. For more details on events, refer to the [GitHub documentation![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fdocs.github.com%2Fen%2Fenterprise-server%403.16%2Fwebhooks%2Fwebhook-events-and-payloads "https://docs.github.com/en/enterprise-server@3.16/webhooks/webhook-events-and-payloads").
Webhook Event | Description
---|---
meta | Occurs when the app is deleted and the associated webhook is removed.
label | Occurs when a label is created, edited, or deleted.
organization | Occurs when an organization is created, deleted, renamed, a member is invited, added, or removed.
public | Occurs when a repository changes from private to public.
push | Occurs when a Git push is made to a repository.
repository | Occurs when a repository is created, deleted, archived, unarchived, publicized, privatized, edited, renamed, or transferred.
workflow_run | Occurs when there is activity related to runs of GitHub Actions workflows.


YesNo
Send
